@@ -118,8 +118,15 @@ bool TipQalc::eventFilter(QObject *object, QEvent *event)
     if (event->type() == QEvent::FocusIn)
     {
         editableLine = qFindChild<QLineEdit*>(this, object->objectName());
+        return true;
     }
-    return false;
+    else
+    {
+        // standard event processing
+        return QObject::eventFilter(object, event);
+    }
+    
+
 }
 
 
@@ -134,6 +141,7 @@ void TipQalc::manageTaxInputWidgets()
     {
         ui->taxLabel->hide();
         ui->taxLine->hide();
+        editableLine = ui->billLine;
     }
     else
     {
